@@ -35,7 +35,9 @@ class CosmosUtility():
 
         cosmos_tenant_client.set_database(database_name)
         cosmos_tenant_client.set_container(container_name)
+        logging.info('tenant_query query started',query)
         result = cosmos_tenant_client.query(query)
+        logging.info('tenant_query query completed',query)
         return result
 
     @cached(cache_platform)
@@ -46,5 +48,7 @@ class CosmosUtility():
             host=cosmos_host, master_key=cosmos_master_key)
         cosmos_client.set_database(platform_db_name)
         cosmos_client.set_container(platform_db_container)
+        logging.info('platform_db_query query started',query)
         result = cosmos_client.query(query)
+        logging.info('platform_db_query query completed',query)
         return result
\ No newline at end of file
